% Determine:
% 1. all points in dataTrain that are lower bounds to points in dataTest
% 2. all points in dataTrain that are upper bounds to points in dataTest
% NOTE: the partial order considered is euclidean, i.e. x is a lower bound
% to y if x(i)<=y(i) for all i.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inputs:  
% dataTrain:  m1 x n data matrix of training data, m1 samples and n features
% dataTest:   m2 x n data matrix of testing data, m2 samples and n features
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Outputs:  
% indsL:      indices of lower bounds, i.e. indsL{i} is a vector of the indices 
%               of training points that are lower bounds to the ith testing point
% indsU:      indices of upper bounds, i.e. indsU{i} is a vector of the indices 
%               of training points that are upper bounds to the ith testing point
% compare:    compare(i)=1 if ith testing point is comparable to something
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modified by Ronny Luss, May 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [indsL,indsU,compare] = find_comparables(dataTrain,dataTest)

numTrain=size(dataTrain,1);
numTest=size(dataTest,1);

indsL=[];
indsU=[];
compare=zeros(numTest,1);
for i=1:numTest
    indsL{i}=find(sum(dataTrain>(ones(numTrain,1)*dataTest(i,:)),2)==0);
    indsU{i}=find(sum(dataTrain<(ones(numTrain,1)*dataTest(i,:)),2)==0);
    if length(indsL{i})+length(indsU{i})>0 % only comparable if has an upper bound, lower bound, or both
        compare(i)=1;
    end
end
